@@ -54,7 +54,7 @@ class Data_inegrator:
 
         self.learning_rate_list = parse_args.learning_rate
         self.activation_fn = activation_fn_dict[parse_args.activation_fn]()
-        self.optimizer - optimizers_dict[parse_args.optimizer]
+        self.optimizer = optimizers_dict[parse_args.optimizer]
         self.latent_layer_size_list = parse_args.latent_representation
         self.klb_coefficient_list = parse_args.klb_coefficient
         self.patience = parse_args.patience
